ChangeLog
=========
0.0.1 (2/22/2024)
    - Added Memory & Chat History
    - Added Simple Chatting Function
    - First Release
0.1.0 (2/23/2024)
    - Added Add Memory Function
    - Added Remove Memory Function
0.1.1 (2/23/2024)
    - Added Function Context
    - Added Simpler Memory Add/Removing